#!/bin/bash

user_dirs=$HOME/.config/user-dirs.dirs
desktop_dir=$HOME/Desktop

if [ -a $user_dirs ]
then
    source $user_dirs
    desktop_dir=$XDG_DESKTOP_DIR
fi

bin_dir=$HOME/.local/bin
app_dir=$HOME/.local/share/applications
icon_dir=$HOME/.local/share/icons

function install_bin()
{
    mkdir -p $bin_dir
    echo "Installing GoPanda2 to $bin_dir"
    cp -p GoPanda2 nw.pak libffmpegsumo.so icudtl.dat $bin_dir/
}

function install_desktop_file()
{
    mkdir -p $desktop_dir
    mkdir -p $app_dir
    echo "Installing desktop file to $desktop_dir and $app_dir"
    cp -p GoPanda2.orig GoPanda2.desktop
    echo "Exec=$bin_dir/GoPanda2" >> GoPanda2.desktop
    echo "Icon=$icon_dir/GoPanda2.png" >> GoPanda2.desktop
    cp -p GoPanda2.desktop $desktop_dir/
    cp -p GoPanda2.desktop $app_dir/
}

function install_icon()
{
    mkdir -p $icon_dir
    echo "Installing icon to $icon_dir"
    cp -p GoPanda2.png $icon_dir/
}

function check_xdg_utils()
{
    command -v xdg-icon-resource >/dev/null 2>&1 || { echo >&2 "File type association requires xdg-utils to be installed."; exit 1; }
    command -v xdg-mime          >/dev/null 2>&1 || { echo >&2 "File type association requires xdg-utils to be installed."; exit 1; }
}

function install_ugi_mime()
{
    check_xdg_utils
    echo "Associating ugi file type"
    xdg-mime install ugf-mime.xml
    xdg-mime install ugi-mime.xml
    xdg-icon-resource install --context mimetypes --size 192 $icon_dir/GoPanda2.png application-x-go-ugf
    xdg-icon-resource install --context mimetypes --size 192 $icon_dir/GoPanda2.png application-x-go-ugi
    xdg-mime default GoPanda2.desktop application/x-go-ugf
    xdg-mime default GoPanda2.desktop application/x-go-ugi
}

function install_sgf_mime()
{
    check_xdg_utils
    echo "Associating sgf file type"
    xdg-mime install sgf-mime.xml
    xdg-icon-resource install --context mimetypes --size 192 $icon_dir/GoPanda2.png application-x-go-sgf
    xdg-mime default GoPanda2.desktop application/x-go-sgf
}

function associate_mime_types()
{
    echo "What file types do you want to associate with GoPanda2?"
    select choice in "Both" "Ugi" "Sgf" "None"; do
        case $choice in
            Both ) install_ugi_mime; install_sgf_mime; break ;;
            Ugi ) install_ugi_mime; break ;;
            Sgf ) install_sgf_mime; break ;;
            None ) break;;
        esac
    done
}

echo ""

install_bin
install_icon
install_desktop_file
associate_mime_types

echo ""
echo "Done!"
echo ""
